define(["../Theme", "./common"], function(Theme, themes){
	
	themes.Harmony=new Theme({
		colors: [
			"#497c91",
			"#59a0bd",
			"#9dc7d9",
			"#c7e0e9",
			"#7b78a4",
			"#8d88c7",
			"#ada9d6",
			"#c9c6e4",
			"#768b4e",
			"#677e13",
			"#a8c179",
			"#c0d0a0",
			"#b7b35c",
			"#e8e667",
			"#eeea99",
			"#f0eebb",
			"#b39c53",
			"#e9c756",
			"#ebcf81",
			"#efdeb0",
			"#956649",
			"#b17044",
			"#c28b69",
			"#cfb09b",
			"#815454",
			"#a05a5a",
			"#c99999",
			"#ddc0c0",
			"#868686",
			"#a5a5a5",
			"#bebebe",
			"#d8d8d8"
		]
	});
	
	return themes.Harmony;
});
